@@ -2,7 +2,6 @@
 corgi entity operations
 
 """
-import concurrent.futures
 import logging
 
 import click
@@ -85,52 +84,25 @@ def components(ctx):
 @click.pass_context
 @progress_bar
 def list_components(ctx, strict_name_search, component_name, **params):
-    # TODO: handle pagination
-    # TODO: handle output
     is_params_empty = [False for v in params.values() if v]
     if not component_name and not is_params_empty:
         click.echo(ctx.get_help())
         exit(0)
+    session = CorgiService.create_session()
     if strict_name_search:
         params["name"] = component_name
     elif component_name:
         params["re_name"] = component_name
-
     if not params["include_fields"]:
         params[
             "include_fields"
         ] = "link,uuid,purl,nvr,version,type,name,upstreams,related_url,download_url"
-
-    session = CorgiService.create_session()
     params = multivalue_params_to_csv(params)
-
-    logger.debug("starting parallel http requests")
-    component_cnt = session.components.retrieve_list(**params).count
-    logger.debug(component_cnt)
-    if component_cnt < 3000000:
-        with concurrent.futures.ThreadPoolExecutor() as executor:
-            futures = []
-            components = list()
-            for batch in range(0, component_cnt, 1200):
-                params["offset"] = batch
-                params["limit"] = 1200
-                futures.append(
-                    executor.submit(
-                        session.components.retrieve_list,
-                        **params,
-                    )
-                )
-
-            for future in concurrent.futures.as_completed(futures):
-                try:
-                    components.extend(future.result().results)
-                except Exception as exc:
-                    logger.warning("%r generated an exception: %s" % (future, exc))
-
-            data = sorted(components, key=lambda d: d.purl)
-            return cprint(data, ctx=ctx)
-    else:
-        console.warning("Too many components.")
+    data = sorted(
+        list(session.components.retrieve_list_iterator_async(max_results=5000, **params)),
+        key=lambda d: d.purl,
+    )
+    return cprint(data, ctx=ctx)
 
 
 @components.command(name="get")
@@ -205,9 +177,10 @@ def get_component_summary(ctx, component_name, strict_name_search, **params):
         "include_fields": "name,type,download_url,purl,tags,arch,release,version,product_streams,upstreams,related_url",  # noqa
         "name": component_name,
     }
-    components = session.components.retrieve_list(**cond, limit=10000)
+    params = multivalue_params_to_csv(params)
+    components = session.components.retrieve_list_iterator_async(**cond)
+    components_cnt = session.components.count(**cond)
     product_streams = []
-    upstreams = []
     versions = []
     releases = []
     arches = []
@@ -215,48 +188,28 @@ def get_component_summary(ctx, component_name, strict_name_search, **params):
     download_urls = []
     tags = []
     component_type = None
-    for component in components.results:
+    for component in components:
         component_type = component.type
         related_urls.append(component.related_url)
         arches.append(component.arch)
         versions.append(component.version)
         releases.append(component.release)
         tags.extend(component.tags)
-        for upstream in component.upstreams:
-            upstreams.append(upstream["purl"])
         for ps in component.product_streams:
             product_streams.append(ps["name"])
-
-    cond = {
-        "include_fields": "name,purl,version,type,tags,arch,release,product_streams",  # noqa
-        "name": component_name,
-        "latest_components_by_streams": True,
-    }
-    # latest_components = session.components.retrieve_list(**cond, limit=10000)
-    #
-    latest = []
-
-    # for latest_component in latest_components.results:
-    #     latest.append(
-    #         {
-    #             "product_stream": latest_component["product_stream"],
-    #             "purl": latest_component.purl,
-    #         }
-    #     )
     data = {
         "link": f"{CORGI_API_URL}/api/v1/components?name={component_name}",
         "type": component_type,
         "name": component_name,
         "tags": sorted(list(set(tags))),
-        "count": len(components.results),
+        "count": components_cnt,
         "product_streams": sorted(list(set(product_streams))),
         "related_urls": sorted(list(set(related_urls))),
         "download_urls": sorted(list(set(download_urls))),
         "releases": sorted(list(set(releases))),
-        "upstreams": sorted(list(set(upstreams))),
+        # "upstreams": sorted(list(set(upstreams))),
         "arches": sorted(list(set(arches))),
         "versions": sorted(list(set(versions))),
-        "latest": latest,
     }
     cprint(data, ctx=ctx)
 
@@ -285,16 +238,18 @@ def get_component_provides(ctx, component_uuid, purl, **params):
         ] = "link,purl,nvr,version,type,name,upstreams,related_url,download_url"
     if purl:
         params["sources"] = purl
-
+    params = multivalue_params_to_csv(params)
     session = CorgiService.create_session()
     if component_uuid:
         purl = session.components.retrieve(component_uuid).purl
         params["sources"] = purl
-        data = session.components.retrieve_list(**params)
-        return cprint(data, ctx=ctx)
+        return cprint(
+            list(components.retrieve_list_iterator_async(max_results=5000, **params)), ctx=ctx
+        )
     else:
-        data = session.components.retrieve_list(**params)
-        return cprint(data, ctx=ctx)
+        return cprint(
+            session.components.retrieve_list_iterator_async(max_results=5000, **params), ctx=ctx
+        )
 
 
 @components.command(name="sources")
@@ -321,15 +276,20 @@ def get_component_sources(ctx, component_uuid, purl, **params):
         ] = "link,purl,nvr,version,type,name,upstreams,related_url,download_url"
     if purl:
         params["provides"] = purl
+    params = multivalue_params_to_csv(params)
     session = CorgiService.create_session()
     if component_uuid:
         purl = session.components.retrieve(component_uuid).purl
         params["provides"] = purl
-        data = session.components.retrieve_list(**params)
-        return cprint(data, ctx=ctx)
+        return cprint(
+            list(session.components.retrieve_list_iterator_async(max_results=5000, **params)),
+            ctx=ctx,
+        )
     else:
-        data = session.components.retrieve_list(**params)
-        return cprint(data, ctx=ctx)
+        return cprint(
+            list(session.components.retrieve_list_iterator_async(max_results=5000, **params)),
+            ctx=ctx,
+        )
 
 
 @components.command(name="manifest")
@@ -420,6 +380,7 @@ def product_streams(ctx):
     },
 )
 @click.pass_context
+@progress_bar
 def list_product_streams(ctx, product_stream_name, **params):
     """Retrieve a list of Product Streams."""
     is_params_empty = [False for v in params.values() if v]
@@ -432,8 +393,11 @@ def list_product_streams(ctx, product_stream_name, **params):
 
     if product_stream_name:
         params["re_name"] = product_stream_name
-    data = session.product_streams.retrieve_list(**params).results
-    return cprint(data, ctx=ctx)
+    params = multivalue_params_to_csv(params)
+    return cprint(
+        list(session.product_streams.retrieve_list_iterator_async(max_results=5000, **params)),
+        ctx=ctx,
+    )
 
 
 @product_streams.command(name="get")
@@ -564,13 +528,16 @@ def builds(ctx):
     },
 )
 @click.pass_context
+@progress_bar
 def list_software_builds(ctx, software_build_name, **params):
     """Retrieve a list of Software Builds."""
     session = CorgiService.create_session()
     if software_build_name:
         params["name"] = software_build_name
-    data = session.builds.retrieve_list(**params).results
-    return cprint(data, ctx=ctx)
+    params = multivalue_params_to_csv(params)
+    return cprint(
+        list(session.builds.retrieve_list_iterator_async(max_results=5000, **params)), ctx=ctx
+    )
 
 
 @builds.command(name="get")
@@ -627,8 +594,10 @@ def list_products(ctx, product_name, **params):
     session = CorgiService.create_session()
     if product_name:
         params["re_name"] = product_name
-    data = session.products.retrieve_list(**params).results
-    return cprint(data, ctx=ctx)
+    params = multivalue_params_to_csv(params)
+    return cprint(
+        list(session.products.retrieve_list_iterator_async(max_results=5000, **params)), ctx=ctx
+    )
 
 
 @products.command(name="get")
@@ -686,8 +655,11 @@ def list_product_versions(ctx, product_version_name, **params):
     session = CorgiService.create_session()
     if product_version_name:
         params["re_name"] = product_version_name
-    data = session.product_versions.retrieve_list(**params).results
-    return cprint(data, ctx=ctx)
+    params = multivalue_params_to_csv(params)
+    return cprint(
+        list(session.product_versions.retrieve_list_iterator_async(max_results=5000, **params)),
+        ctx=ctx,
+    )
 
 
 @product_versions.command(name="get")
@@ -745,8 +717,11 @@ def list_product_variants(ctx, product_variant_name, **params):
     session = CorgiService.create_session()
     if product_variant_name:
         params["re_name"] = product_variant_name
-    data = session.product_variants.retrieve_list(**params).results
-    return cprint(data, ctx=ctx)
+    params = multivalue_params_to_csv(params)
+    return cprint(
+        list(session.product_variants.retrieve_list_iterator_async(max_results=5000, **params)),
+        ctx=ctx,
+    )
 
 
 @product_variants.command(name="get")
@@ -804,8 +779,10 @@ def list_channels(ctx, channel_name, **params):
     session = CorgiService.create_session()
     if channel_name:
         params["re_name"] = channel_name
-    data = session.channels.retrieve_list(**params).results
-    return cprint(data, ctx=ctx)
+    params = multivalue_params_to_csv(params)
+    return cprint(
+        list(session.channels.retrieve_list_iterator_async(max_results=5000, **params)), ctx=ctx
+    )
 
 
 @channels.command(name="get")
@@ -858,6 +835,7 @@ def corgi_status(ctx):
 
 @manage_grp.command(name="health")
 @click.pass_context
+@progress_bar
 def corgi_health(ctx):
     try:
         session = CorgiService.create_session()
