@@ -1,4 +1,8 @@
 """
+    read only cli commands
+
+    Note - the command op hierarchy is verbose by design as we will want to reuse
+    these operations beyond cli
 
 """
 import copy
@@ -194,7 +198,7 @@ def retrieve_component_summary(ctx, component_name, strict_name_search):
 @click.option(
     "--flaw-mode",
     "flaw_mode",
-    default="dry_run",
+    default="add",
     type=click.Choice(["add", "replace", "dry_run"]),
     help="Add or update when generating affects.",
 )
@@ -267,6 +271,13 @@ def retrieve_component_summary(ctx, component_name, strict_name_search):
     default=False,
     help="Do not search middleware.",
 )
+@click.option(
+    "--no-upstream-affects",
+    "no_upstream_affects",
+    is_flag=True,
+    default=False,
+    help="Do not generate upstream affects.",
+)
 @click.option(
     "--include-inactive-product-streams",
     "include_inactive_product_streams",
@@ -317,6 +328,7 @@ def get_product_contain_component(
     search_upstreams,
     no_community,
     no_middleware,
+    no_upstream_affects,
     include_inactive_product_streams,
     include_product_stream_excluded_components,
     output_type_filter,
@@ -349,14 +361,19 @@ def get_product_contain_component(
         params.pop("flaw_mode")
         params.pop("affect_mode")
         if component_name:
-            q = query_service.invoke(core_queries.products_containing_component_query, params)
+            q = query_service.invoke(
+                core_queries.products_containing_component_query, params, status=operation_status
+            )
         if purl:
             q = query_service.invoke(
-                core_queries.products_containing_specific_component_query, params
+                core_queries.products_containing_specific_component_query,
+                params,
+                status=operation_status,
             )
 
         # TODO: interim hack for middleware
         if component_name and MIDDLEWARE_CLI and not no_middleware:
+            operation_status.update("griffoning: searching deptopia middleware.", spinner="line")
             mw_command = [MIDDLEWARE_CLI, component_name, "-e", "maven", "--json"]
             if strict_name_search:
                 mw_command.append("-s")
@@ -365,48 +382,53 @@ def get_product_contain_component(
                 capture_output=True,
                 text=True,
             )
-            mw_json = loads(proc.stdout)
-            mw_components = mw_json["deps"]
-            # TODO: need to determine if we use "build" or "deps"
-            # if search_all:
-            #     mw_components.extend(mw_json["deps"])
-            for build in mw_components:
-                if build["build_type"] == "maven":
-                    component = {
-                        "product_versions": [{"name": build["ps_module"]}],
-                        "product_streams": [
-                            {
-                                "name": build["ps_update_stream"],
-                                "product_versions": [{"name": build["ps_module"]}],
-                            }
-                        ],
-                        "product_active": True,
-                        "type": build["build_type"],
-                        "name": build["build_name"],
-                        "nvr": build["build_nvr"],
-                        "upstreams": [],
-                        "sources": [],
-                        "software_build": {
-                            "build_id": build["build_id"],
-                            "source": build["build_repo"],
-                        },
-                    }
-                    if "sources" in build:
-                        for deps in build["sources"]:
-                            for dep in deps["dependencies"]:
-                                components = []
-                                components.append(
-                                    {
-                                        "name": dep.get("name"),
-                                        "nvr": dep.get("nvr"),
-                                        "type": dep.get("type"),
-                                    }
-                                )
-                                component["sources"] = components
-                    q.append(component)
+            try:
+                mw_json = loads(proc.stdout)
+                mw_components = mw_json["deps"]
+                # TODO: need to determine if we use "build" or "deps"
+                # if search_all:
+                #     mw_components.extend(mw_json["deps"])
+                for build in mw_components:
+                    if build["build_type"] == "maven":
+                        component = {
+                            "product_versions": [{"name": build["ps_module"]}],
+                            "product_streams": [
+                                {
+                                    "name": build["ps_update_stream"],
+                                    "product_versions": [{"name": build["ps_module"]}],
+                                }
+                            ],
+                            "product_active": True,
+                            "type": build["build_type"],
+                            "name": build["build_name"],
+                            "nvr": build["build_nvr"],
+                            "upstreams": [],
+                            "sources": [],
+                            "software_build": {
+                                "build_id": build["build_id"],
+                                "source": build["build_repo"],
+                            },
+                        }
+                        if "sources" in build:
+                            for deps in build["sources"]:
+                                for dep in deps["dependencies"]:
+                                    components = []
+                                    components.append(
+                                        {
+                                            "name": dep.get("name"),
+                                            "nvr": dep.get("nvr"),
+                                            "type": dep.get("type"),
+                                        }
+                                    )
+                                    component["sources"] = components
+                        q.append(component)
+            except Exception:
+                logger.warning("problem accessing deptopia.")
 
         # TODO: in the short term affect handling will be mediated via sfm2 here in the operation itself # noqa
         if ctx.params["sfm2_flaw_id"]:
+            operation_status.update("griffoning: invoking sfm2.", spinner="line")
+
             console.no_color = True
             console.highlighter = None
             operation_status.stop()
@@ -769,12 +791,6 @@ def product_versions_affected_by_cve_query(ctx, cve_id):
 @queries_grp.command(name="component-flaws", help="List Flaws affecting a Component.")
 @click.argument("component_name", required=False)
 @click.option("--purl")
-@click.option(
-    "--flaw-state",
-    "flaw_state",
-    help="Filter by Flaw state.",
-    type=click.Choice(OSIDBService.get_flaw_states()),
-)
 @click.option(
     "--flaw-impact",
     "flaw_impact",
@@ -817,7 +833,6 @@ def cves_for_specific_component_query(
     ctx,
     component_name,
     purl,
-    flaw_state,
     flaw_impact,
     flaw_resolution,
     affectedness,
@@ -845,12 +860,6 @@ def cves_for_specific_component_query(
     shell_complete=get_product_version_names,
 )
 @click.option("--ofuri")
-@click.option(
-    "--flaw-state",
-    "flaw_state",
-    help="Filter by Flaw state.",
-    type=click.Choice(OSIDBService.get_flaw_states()),
-)
 @click.option(
     "--flaw-impact",
     "flaw_impact",
@@ -893,7 +902,6 @@ def cves_for_specific_product_query(
     ctx,
     product_version_name,
     ofuri,
-    flaw_state,
     flaw_impact,
     flaw_resolution,
     affectedness,
